pub enum LedgerEntry {
Purchased {
sessions: SessionCount,
},
Reserved {
session_id: SessionId,
},
Consumed {
session_id: SessionId,
},
Released {
session_id: SessionId,
},
}Expand description
Training package ledger event for purchases, reservations, consumption, and releases.
Variants
Purchased
Sessions used by staff to prepare training assignment, package, progress, or parent-summary review.
Fields

sessions: SessionCountSession count that sets the purchased or reusable package balance.
Reserved
Session identifier used by staff to prepare training assignment, package, progress, or parent-summary review.
Consumed
Session identifier used by staff to prepare training assignment, package, progress, or parent-summary review.
Released
Session identifier used by staff to prepare training assignment, package, progress, or parent-summary review.