pub enum Policy {
PayPerSession,
MultiSessionPackage {
sessions: SessionCount,
},
BoardAndTrainBundle,
}Expand description
Groomer-assignment policies used when booking grooming work.
Variants
PayPerSession
Staff can see the pay per session training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
MultiSessionPackage
Sessions used by staff to prepare training assignment, package, progress, or parent-summary review.
Fields

sessions: SessionCountSession count that sets the purchased or reusable package balance.
BoardAndTrainBundle
Staff can see the board and train bundle training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.