UsageDecision

Enum UsageDecision 

pub enum UsageDecision {
    ReserveNextSession {
        package_id: Id,
        remaining_after_reservation: SessionBalance,
    },
    NoRemainingSessions {
        package_id: Id,
        gate: ReviewGate,
    },
    ReconciliationRequired {
        package_id: Id,
        gate: ReviewGate,
    },
}
Package usage decision for reserving the next session or escalating balance/reconciliation issues.

Variants



ReserveNextSession

Staff can see the reserve next session training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.

Fields

package_id: Id

Package identifier used by staff to prepare training assignment, package, progress, or parent-summary review.

remaining_after_reservation: SessionBalance

Remaining after reservation used by staff to prepare training assignment, package, progress, or parent-summary review.



NoRemainingSessions

Staff can see the no remaining sessions training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.

Fields

package_id: Id

Package identifier used by staff to prepare training assignment, package, progress, or parent-summary review.

gate: ReviewGate

Review gate that must clear before this training decision affects assignment, package use, or parent-facing copy.



ReconciliationRequired

Staff can see the reconciliation required training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.

Fields

package_id: Id

Package identifier used by staff to prepare training assignment, package, progress, or parent-summary review.

gate: ReviewGate

Review gate that must clear before this training decision affects assignment, package use, or parent-facing copy.