UsageDecision

Enum UsageDecision 

pub enum UsageDecision {
    ReserveNextSession {
        package_id: Id,
        remaining_after_reservation: SessionBalance,
    },
    NoRemainingSessions {
        package_id: Id,
        gate: ReviewGate,
    },
    ReconciliationRequired {
        package_id: Id,
        gate: ReviewGate,
    },
}
Package usage decision for reserving the next session or escalating balance/reconciliation issues.

Variants



ReserveNextSession

Reserve next session training operational signal for enrollment, curriculum, progress, package, or follow-up handling.

Fields

package_id: Id

Source-derived package id carried by this training contract.

remaining_after_reservation: SessionBalance

Source-derived remaining after reservation carried by this training contract.



NoRemainingSessions

No remaining sessions training operational signal for enrollment, curriculum, progress, package, or follow-up handling.

Fields

package_id: Id

Source-derived package id carried by this training contract.

gate: ReviewGate

Source-derived gate carried by this training contract.



ReconciliationRequired

Reconciliation required training operational signal for enrollment, curriculum, progress, package, or follow-up handling.

Fields

package_id: Id

Source-derived package id carried by this training contract.

gate: ReviewGate

Source-derived gate carried by this training contract.